Struct lunatic_diesel::backend::sql_dialect::batch_insert_support::DoesNotSupportBatchInsert
source · pub struct DoesNotSupportBatchInsert;Expand description
Indicates that this backend does not support batch insert statements. In this case diesel will emulate batch insert support by inserting each row on it’s own