pub enum StatementCacheKey<DB>where
DB: Backend,{
Type(TypeId),
Sql {
sql: String,
bind_types: Vec<<DB as TypeMetadata>::TypeMetadata, Global>,
},
}Expand description
The lookup key used by StatementCache internally
This can contain either a at compile time known type id (representing a statically known query) or a at runtime calculated query string + parameter types (for queries that may change depending on their parameters)
Variants
Type(TypeId)
Represents a at compile time known query
Calculated via QueryId::QueryId
Sql
Fields

bind_types: Vec<<DB as TypeMetadata>::TypeMetadata, Global>contains the types of any bind parameter passed to the query
Represents a dynamically constructed query
This variant is used if QueryId::HAS_STATIC_QUERY_ID
is false and AstPass::unsafe_to_cache_prepared is not
called for a given query.
Implementations
sourceimpl<DB> StatementCacheKey<DB>where
DB: Backend,
<DB as Backend>::QueryBuilder: Default,
<DB as TypeMetadata>::TypeMetadata: Clone,
impl<DB> StatementCacheKey<DB>where
DB: Backend,
<DB as Backend>::QueryBuilder: Default,
<DB as TypeMetadata>::TypeMetadata: Clone,
sourcepub fn for_source<T>(
source: &T,
bind_types: &[<DB as TypeMetadata>::TypeMetadata],
backend: &DB
) -> Result<StatementCacheKey<DB>, Error>where
T: QueryFragment<DB, NotSpecialized> + QueryId,
pub fn for_source<T>(
source: &T,
bind_types: &[<DB as TypeMetadata>::TypeMetadata],
backend: &DB
) -> Result<StatementCacheKey<DB>, Error>where
T: QueryFragment<DB, NotSpecialized> + QueryId,
Create a new statement cache key for the given query source